@@ -15,7 +15,7 @@ Example:
         In [1]: from neuprint import Client, fetch_custom, fetch_neurons
 
         In [2]: # Create a default client. Will be implicitly used for all subsequent queries.
-           ...: c = Client('neuprint.janelia.org', dataset='hemibrain:v1.0')
+           ...: c = Client('neuprint.janelia.org', dataset='hemibrain:v1.2.1')
 
         In [3]: fetch_custom("""\\
            ...:     MATCH (n: Neuron)
@@ -110,8 +110,8 @@ def setup_debug_logging():
                ...: from neuprint import fetch_neurons, NeuronCriteria as NC
                ...:
                ...: setup_debug_logging()
-               ...: neuron_df, roi_df = fetch_neurons(NC(type='MBON.*', rois=['MB(R)'], regex=True))
-            [2020-01-30 08:48:20,367] DEBUG Performing cypher query against dataset 'hemibrain:v1.0':
+               ...: neuron_df, roi_df = fetch_neurons(NC(type='MBON.*', rois=['MB(R)']))
+            [2020-01-30 08:48:20,367] DEBUG Performing cypher query against dataset 'hemibrain:v1.2.1':
                 MATCH (n :Neuron)
                 // -- Basic conditions for segment 'n' --
                 WHERE
@@ -721,7 +721,7 @@ class Client:
             df = skeleton_swc_to_df(swc)
 
         if heal:
-            df = heal_skeleton(df, heal)
+            df = heal_skeleton(df, heal, -1)
             if export_path or format == 'swc':
                 swc = skeleton_df_to_swc(df)
 
